@@ -5,19 +5,29 @@ from __future__ import unicode_literals
 ADJECTIVES_IRREG = {
     "χειρότερος": ("κακός",),
     "χειρότερη": ("κακός",),
+    "χειρότερης": ("κακός",),
     "χειρότερο": ("κακός",),
+    "χειρότεροι": ("κακός",),
+    "χειρότερων": ("κακός",),
+    "χειρότερου": ("κακός",),
     "βέλτιστος": ("καλός",),
     "βέλτιστη": ("καλός",),
+    "βέλτιστης": ("καλός",),
     "βέλτιστο": ("καλός",),
     "βέλτιστοι": ("καλός",),
     "βέλτιστων": ("καλός",),
+    "βέλτιστου": ("καλός",),
     "ελάχιστος": ("λίγος",),
     "ελάχιστα": ("λίγος",),
     "ελάχιστοι": ("λίγος",),
     "ελάχιστων": ("λίγος",),
     "ελάχιστη": ("λίγος",),
+    "ελάχιστης": ("λίγος",),
     "ελάχιστο": ("λίγος",),
+    "ελάχιστου": ("λίγος",),
     "πλείστος": ("πολύς",),
+    "πλείστου": ("πολύς",),
+    "πλείστων": ("πολύς",),
     "πολλή": ("πολύ",),
     "πολύς": ("πολύ",),
     "πολλύ": ("πολύ",),
